==> jc-1.4.0.tar.gz: soot/options/CHAOptions.h <==
// public class soot.options.CHAOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d1c546f5a6eca609 soot_options_CHAOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_CHAOptions_H_
#define _JC_soot_options_CHAOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_CHAOptions$sub_refs	_jc_soot_options_CHAOptions$sub_refs;
typedef struct _jc_soot_options_CHAOptions$sub_nonrefs	_jc_soot_options_CHAOptions$sub_nonrefs;
typedef struct _jc_soot_options_CHAOptions$refs	_jc_soot_options_CHAOptions$refs;
typedef struct _jc_soot_options_CHAOptions$nonrefs	_jc_soot_options_CHAOptions$nonrefs;
typedef struct _jc_soot_options_CHAOptions$object	_jc_soot_options_CHAOptions$object;

typedef const struct _jc_soot_options_CHAOptions$vmethods	_jc_soot_options_CHAOptions$vmethods;
typedef const struct _jc_soot_options_CHAOptions$vtable	_jc_soot_options_CHAOptions$vtable;
typedef const struct _jc_soot_options_CHAOptions$vtype	_jc_soot_options_CHAOptions$vtype;

// Constructors
extern void _jc_soot_options_CHAOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_CHAOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_CHAOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_CHAOptions$object *);
extern jboolean _jc_soot_options_CHAOptions$method$verbose$e5b65d4727121643(_jc_env *, struct _jc_soot_options_CHAOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_CHAOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_CHAOptions$method_info$verbose$e5b65d4727121643;

// Virtual methods structure
struct _jc_soot_options_CHAOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_CHAOptions$object *);
	jboolean	(*verbose$e5b65d4727121643)(_jc_env *, struct _jc_soot_options_CHAOptions$object *);
};

// Vtable
struct _jc_soot_options_CHAOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_CHAOptions$vmethods	soot_options_CHAOptions;
};

// Vtype
struct _jc_soot_options_CHAOptions$vtype {
	_jc_type			type;
	_jc_soot_options_CHAOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_CHAOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_CHAOptions$refs {
    _jc_soot_options_CHAOptions$sub_refs	soot_options_CHAOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_CHAOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_CHAOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_CHAOptions$sub_nonrefs	soot_options_CHAOptions;
};

// Object instance structure
struct _jc_soot_options_CHAOptions$object {
	_jc_soot_options_CHAOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_CHAOptions$vtype	*vtype;
	_jc_soot_options_CHAOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_CHAOptions$vtype _jc_soot_options_CHAOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_CHAOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_CHAOptions$class_object;

#endif	/* _JC_soot_options_CHAOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/CHAOptions.h <==
// public class soot.options.CHAOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d1c546f5a6eca609 soot_options_CHAOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_CHAOptions_H_
#define _JC_soot_options_CHAOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_CHAOptions$sub_refs	_jc_soot_options_CHAOptions$sub_refs;
typedef struct _jc_soot_options_CHAOptions$sub_nonrefs	_jc_soot_options_CHAOptions$sub_nonrefs;
typedef struct _jc_soot_options_CHAOptions$refs	_jc_soot_options_CHAOptions$refs;
typedef struct _jc_soot_options_CHAOptions$nonrefs	_jc_soot_options_CHAOptions$nonrefs;
typedef struct _jc_soot_options_CHAOptions$object	_jc_soot_options_CHAOptions$object;

typedef const struct _jc_soot_options_CHAOptions$vmethods	_jc_soot_options_CHAOptions$vmethods;
typedef const struct _jc_soot_options_CHAOptions$vtable	_jc_soot_options_CHAOptions$vtable;
typedef const struct _jc_soot_options_CHAOptions$vtype	_jc_soot_options_CHAOptions$vtype;

// Constructors
extern void _jc_soot_options_CHAOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_CHAOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_CHAOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_CHAOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CHAOptions$method$verbose$e5b65d4727121643(_jc_env *, struct _jc_soot_options_CHAOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_CHAOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_CHAOptions$method_info$verbose$e5b65d4727121643;

// Virtual methods structure
struct _jc_soot_options_CHAOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_CHAOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*verbose$e5b65d4727121643)(_jc_env *, struct _jc_soot_options_CHAOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_CHAOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_CHAOptions$vmethods	soot_options_CHAOptions;
};

// Vtype
struct _jc_soot_options_CHAOptions$vtype {
	_jc_type			type;
	_jc_soot_options_CHAOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_CHAOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_CHAOptions$refs {
    _jc_soot_options_CHAOptions$sub_refs	soot_options_CHAOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_CHAOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_CHAOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_CHAOptions$sub_nonrefs	soot_options_CHAOptions;
};

// Object instance structure
struct _jc_soot_options_CHAOptions$object {
	_jc_soot_options_CHAOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_CHAOptions$vtype	*vtype;
	_jc_soot_options_CHAOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_CHAOptions$vtype _jc_soot_options_CHAOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_CHAOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_CHAOptions$class_object;

#endif	/* _JC_soot_options_CHAOptions_H_ */
